.. currentmodule:: sardana.macroserver.msmacromanager

:mod:`~sardana.macroserver.msmacromanager`
===========================================

.. automodule:: sardana.macroserver.msmacromanager

.. rubric:: Functions

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`MacroManager`
    * :class:`MacroExecutor`
    
MacroManager
--------------------

.. autoclass:: MacroManager
    :show-inheritance:

MacroExecutor
--------------------

.. autoclass:: MacroExecutor
    :show-inheritance: